"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.sleep = void 0;
const chai_1 = __importStar(require("chai"));
const chai_as_promised_1 = __importDefault(require("chai-as-promised"));
chai_1.default.use(chai_as_promised_1.default);
const dotenv = __importStar(require("dotenv"));
const service_authorization_1 = require("@itwin/service-authorization");
const axios_1 = __importStar(require("axios"));
const axios_mock_adapter_1 = __importDefault(require("axios-mock-adapter"));
const ContextCaptureService_1 = require("./ContextCaptureService");
const Utils_1 = require("./Utils");
const reality_capture_common_1 = require("@itwin/reality-capture-common");
const path_1 = __importDefault(require("path"));
async function sleep(ms) { return new Promise(resolve => setTimeout(resolve, ms)); }
exports.sleep = sleep;
describe("Reality Modeling unit tests", () => {
    const serviceUrl = "https://api.bentley.com/contextcapture";
    let contextCaptureService;
    let axiosMock = new axios_mock_adapter_1.default(axios_1.default);
    let authorizationClient;
    before(async function () {
        this.timeout(30000);
        dotenv.config({ path: path_1.default.resolve(__dirname, "../../../../../.env") });
        const clientId = process.env.IMJS_UNIT_TESTS_CLIENT_ID ?? "";
        const secret = process.env.IMJS_UNIT_TESTS_SECRET ?? "";
        authorizationClient = new service_authorization_1.ServiceAuthorizationClient({
            clientId: clientId,
            clientSecret: secret,
            scope: Array.from(ContextCaptureService_1.ContextCaptureService.getScopes()).join(" "),
            authority: "https://ims.bentley.com",
        });
        contextCaptureService = new ContextCaptureService_1.ContextCaptureService(authorizationClient.getAccessToken.bind(authorizationClient));
    });
    beforeEach(async function () {
        axiosMock = new axios_mock_adapter_1.default(axios_1.default);
    });
    afterEach(async function () {
        axiosMock.resetHistory();
    });
    describe("Create job", () => {
        it("Create valid job", async function () {
            this.timeout(2500);
            axiosMock.onPost(serviceUrl + "/jobs", {
                "type": "Full",
                "inputs": [{ "id": "imagesId" }, { "id": "ccOrientationsId" }],
                "name": "Reality Modeling unit test job",
                "settings": {
                    "outputs": ["OPC", "CCOrientations"],
                    "cacheSettings": { "createCache": true, "useCache": "useCache" },
                    "quality": "Extra",
                    "processingEngines": 5
                },
                "workspaceId": "workspaceId"
            }).reply(201, {
                "job": {
                    "id": "cc3d35cc-416a-4262-9714-b359da70b419",
                    "name": "Reality Modeling unit test job",
                    "type": "Full",
                    "state": "unsubmitted",
                    "createdDateTime": "2023-04-05T14:29:55Z",
                    "lastModifiedDateTime": "2023-04-05T14:29:55Z",
                    "iTwinId": "c3739cf2-9da3-487b-b03d-f58c8eb97e5b",
                    "location": "East US",
                    "email": "example@bentley.com",
                    "workspaceId": "workspaceId",
                    "inputs": [{ "id": "imagesId" }, { "id": "ccOrientationsId" }],
                    "jobSettings": {
                        "quality": "Extra",
                        "outputs": [{
                                "format": "OPC",
                                "id": "opcId"
                            },
                            {
                                "format": "CCOrientations",
                                "id": "orientationsId"
                            }
                        ],
                        "processingEngines": 5,
                        "cacheSettings": {
                            "createCache": true,
                            "useCache": "799b11bd-71cf-481a-b284-bf48f672cd9a"
                        }
                    }
                }
            });
            const ccSettings = new Utils_1.CCJobSettings();
            ccSettings.inputs = ["imagesId", "ccOrientationsId"];
            ccSettings.outputs.opc = "opc";
            ccSettings.outputs.orientations = "orientations";
            ccSettings.engines = 5;
            ccSettings.meshQuality = Utils_1.CCJobQuality.EXTRA;
            ccSettings.cacheSettings = {
                useCache: "useCache",
                createCache: true
            };
            const jobName = "Reality Modeling unit test job";
            const id = contextCaptureService.createJob(Utils_1.CCJobType.FULL, ccSettings, jobName, "workspaceId");
            await sleep(2000);
            if (axiosMock.history.post.length === 0)
                return (0, chai_1.expect)(axiosMock.history.post.length).equal(1, "Mock adapter has not been called as expected.");
            const body = JSON.parse(axiosMock.history.post[0].data);
            return Promise.all([
                (0, chai_1.expect)(body).to.have.property("type", "Full"),
                (0, chai_1.expect)(body).to.have.property("name", "Reality Modeling unit test job"),
                (0, chai_1.expect)(body).to.have.property("workspaceId", "workspaceId"),
                (0, chai_1.expect)(body).to.have.property("inputs"),
                (0, chai_1.expect)(body.inputs).to.have.length.above(0),
                (0, chai_1.expect)(body.inputs).to.deep.include({ "id": "imagesId" }),
                (0, chai_1.expect)(body.inputs).to.deep.include({ "id": "ccOrientationsId" }),
                (0, chai_1.expect)(body.settings).to.have.property("quality", "Extra"),
                (0, chai_1.expect)(body.settings).to.have.property("processingEngines", 5),
                (0, chai_1.expect)(body.settings.outputs).to.have.length.above(0),
                (0, chai_1.expect)(body.settings.outputs).to.deep.include("OPC"),
                (0, chai_1.expect)(body.settings.outputs).to.deep.include("CCOrientations"),
                (0, chai_1.expect)(id).to.eventually.deep.equal("cc3d35cc-416a-4262-9714-b359da70b419"),
            ]);
        });
    });
    describe("Private submit request", () => {
        it("Get", async function () {
            axiosMock.onGet(serviceUrl + "/jobs/id1").reply(200, {});
            const res = contextCaptureService.submitRequest("jobs/id1", "GET", [200]);
            await sleep(500);
            if (axiosMock.history.get.length === 0)
                return (0, chai_1.expect)(axiosMock.history.get.length).equal(1, "Mock adapter has not been called as expected.");
            return (0, chai_1.expect)(res).to.eventually.deep.equal({});
        });
        it("Invalid method", async function () {
            axiosMock.onGet(serviceUrl + "/jobs/id2").reply(200, {});
            const res = contextCaptureService.submitRequest("jobs/id2", "INVALID", [200]);
            return (0, chai_1.expect)(res).to.eventually.be.rejectedWith(Error).and.have.property("message", "Wrong request method");
        });
        it("Wrong response code", async function () {
            axiosMock.onGet(serviceUrl + "/jobs/id3").reply(201, {});
            const res = contextCaptureService.submitRequest("jobs/id3", "GET", [200]);
            await sleep(500);
            if (axiosMock.history.get.length === 0)
                return (0, chai_1.expect)(axiosMock.history.get.length).equal(1, "Mock adapter has not been called as expected.");
            return (0, chai_1.expect)(res).to.eventually.be.rejectedWith(Error).and.have.property("message", "Wrong request response code, expected : 200");
        });
        it("Axios error", async function () {
            const axiosResponse = { data: { error: { message: "Axios error" } }, status: 404, statusText: "404" };
            axiosMock.onGet(serviceUrl + "/jobs/id4").reply(() => Promise.reject(new axios_1.AxiosError("Axios error", "404", undefined, undefined, axiosResponse)));
            const res = contextCaptureService.submitRequest("jobs/id4", "GET", [200]);
            await sleep(500);
            if (axiosMock.history.get.length === 0)
                return (0, chai_1.expect)(axiosMock.history.get.length).equal(1, "Mock adapter has not been called as expected.");
            return (0, chai_1.expect)(res).to.eventually.be.rejectedWith(Error).and.have.property("message", "Error 404 Axios error");
        });
        it("Error", async function () {
            axiosMock.onGet(serviceUrl + "/jobs/id5").reply(() => Promise.reject(new Error("Error")));
            const res = contextCaptureService.submitRequest("jobs/id5", "GET", [200]);
            await sleep(500);
            if (axiosMock.history.get.length === 0)
                return (0, chai_1.expect)(axiosMock.history.get.length).equal(1, "Mock adapter has not been called as expected.");
            return (0, chai_1.expect)(res).to.eventually.be.rejectedWith(Error).and.have.property("message", "Error");
        });
    });
    describe("Create workspace", () => {
        it("Create workspace", async function () {
            const body = {
                "name": "Unit tests workspace name",
                "iTwinId": "3fa85f64-5717-4562-b3fc-2c963f66afa6",
                "contextCaptureVersion": "20.1"
            };
            axiosMock.onPost(serviceUrl + "/workspaces", body).reply(201, {
                "workspace": {
                    "id": "e47cf092-729a-4ce2-b20e-9b01ad820cdb",
                    "createdDateTime": "2023-04-07T09:39:23.436Z",
                    "name": "Unit tests workspace name",
                    "iTwinId": "3fa85f64-5717-4562-b3fc-2c963f66afa6",
                    "contextCaptureVersion": "20.1"
                }
            });
            const res = contextCaptureService.createWorkspace("Unit tests workspace name", "3fa85f64-5717-4562-b3fc-2c963f66afa6", "20.1");
            await sleep(500);
            if (axiosMock.history.post.length === 0)
                return (0, chai_1.expect)(axiosMock.history.post.length).equal(1, "Mock adapter has not been called as expected.");
            return (0, chai_1.expect)(res).to.eventually.deep.equal("e47cf092-729a-4ce2-b20e-9b01ad820cdb");
        });
    });
    describe("Delete workspace", () => {
        it("Delete workspace", async function () {
            axiosMock.onDelete(serviceUrl + "/workspaces/workspace").reply(204, {});
            const res = contextCaptureService.deleteWorkspace("workspace");
            await sleep(500);
            if (axiosMock.history.delete.length === 0)
                return (0, chai_1.expect)(axiosMock.history.delete.length).equal(1, "Mock adapter has not been called as expected.");
            return (0, chai_1.expect)(res).to.eventually.deep.equal({});
        });
    });
    describe("Get workspace", () => {
        it("Get workspace", async function () {
            axiosMock.onGet(serviceUrl + "/workspaces/workspace").reply(200, {
                "workspace": {
                    "id": "e47cf092-729a-4ce2-b20e-9b01ad820cdb",
                    "createdDateTime": "2023-04-07T09:39:23.436Z",
                    "name": "Unit tests workspace name",
                    "iTwinId": "3fa85f64-5717-4562-b3fc-2c963f66afa6",
                    "contextCaptureVersion": "20.1"
                }
            });
            const workspace = contextCaptureService.getWorkspace("workspace");
            await sleep(500);
            if (axiosMock.history.get.length === 0)
                return (0, chai_1.expect)(axiosMock.history.get.length).equal(1, "Mock adapter has not been called as expected.");
            return Promise.all([
                (0, chai_1.expect)(workspace).to.eventually.have.property("id", "e47cf092-729a-4ce2-b20e-9b01ad820cdb"),
                (0, chai_1.expect)(workspace).to.eventually.have.property("createdDateTime", "2023-04-07T09:39:23.436Z"),
                (0, chai_1.expect)(workspace).to.eventually.have.property("name", "Unit tests workspace name"),
                (0, chai_1.expect)(workspace).to.eventually.have.property("iTwinId", "3fa85f64-5717-4562-b3fc-2c963f66afa6"),
                (0, chai_1.expect)(workspace).to.eventually.have.property("contextCaptureVersion", "20.1"),
            ]);
        });
    });
    describe("Submit job", () => {
        it("Submit valid job", async function () {
            axiosMock.onPatch(serviceUrl + "/jobs/validId", { "state": "active" }).reply(200, {});
            const res = contextCaptureService.submitJob("validId");
            await sleep(500);
            if (axiosMock.history.patch.length === 0)
                return (0, chai_1.expect)(axiosMock.history.patch.length).equal(1, "Mock adapter has not been called as expected.");
            return (0, chai_1.expect)(res).to.eventually.deep.equal({});
        });
    });
    describe("Cancel", () => {
        it("Cancel existing job", async function () {
            axiosMock.onPatch(serviceUrl + "/jobs/validId", { "state": "cancelled" }).reply(200, {});
            const res = contextCaptureService.cancelJob("validId");
            await sleep(500);
            if (axiosMock.history.patch.length === 0)
                return (0, chai_1.expect)(axiosMock.history.patch.length).equal(1, "Mock adapter has not been called as expected.");
            return (0, chai_1.expect)(res).to.eventually.deep.equal({});
        });
    });
    describe("Delete", () => {
        it("Delete existing job", async function () {
            axiosMock.onDelete(serviceUrl + "/jobs/validId").reply(204, {});
            const res = contextCaptureService.deleteJob("validId");
            await sleep(500);
            if (axiosMock.history.delete.length === 0)
                return (0, chai_1.expect)(axiosMock.history.delete.length).equal(1, "Mock adapter has not been called as expected.");
            return (0, chai_1.expect)(res).to.eventually.deep.equal({});
        });
    });
    describe("Get job progress", () => {
        it("Get active job progress", async function () {
            axiosMock.onGet(serviceUrl + "/jobs/validId/progress").reply(200, { "jobProgress": { "percentage": 56, "state": "active", "step": "Run_Production" } });
            const res = contextCaptureService.getJobProgress("validId");
            await sleep(500);
            if (axiosMock.history.get.length === 0)
                return (0, chai_1.expect)(axiosMock.history.get.length).equal(1, "Mock adapter has not been called as expected.");
            return (0, chai_1.expect)(res).to.eventually.deep.equal({ state: reality_capture_common_1.JobState.ACTIVE, progress: 56, step: "Run_Production" });
        });
        it("Get failed job progress", async function () {
            axiosMock.onGet(serviceUrl + "/jobs/failedId/progress").reply(200, { "jobProgress": { "percentage": 3, "state": "failed", "step": "Prepare_Step" } });
            const res = contextCaptureService.getJobProgress("failedId");
            await sleep(500);
            if (axiosMock.history.get.length === 0)
                return (0, chai_1.expect)(axiosMock.history.get.length).equal(1, "Mock adapter has not been called as expected.");
            return (0, chai_1.expect)(res).to.eventually.deep.equal({ state: reality_capture_common_1.JobState.FAILED, progress: 3, step: "Prepare_Step" });
        });
        it("Get success job progress", async function () {
            axiosMock.onGet(serviceUrl + "/jobs/successId/progress").reply(200, { "jobProgress": { "percentage": 100, "state": "success", "step": "Final_Step" } });
            const res = contextCaptureService.getJobProgress("successId");
            await sleep(500);
            if (axiosMock.history.get.length === 0)
                return (0, chai_1.expect)(axiosMock.history.get.length).equal(1, "Mock adapter has not been called as expected.");
            return (0, chai_1.expect)(res).to.eventually.deep.equal({ state: reality_capture_common_1.JobState.SUCCESS, progress: 100, step: "Final_Step" });
        });
        it("Get cancelled job progress", async function () {
            axiosMock.onGet(serviceUrl + "/jobs/cancelId/progress").reply(200, { "jobProgress": { "percentage": 3, "state": "cancelled", "step": "Prepare_Step" } });
            const res = contextCaptureService.getJobProgress("cancelId");
            await sleep(500);
            if (axiosMock.history.get.length === 0)
                return (0, chai_1.expect)(axiosMock.history.get.length).equal(1, "Mock adapter has not been called as expected.");
            return (0, chai_1.expect)(res).to.eventually.deep.equal({ state: reality_capture_common_1.JobState.CANCELLED, progress: 3, step: "Prepare_Step" });
        });
        it("Get over job progress", async function () {
            axiosMock.onGet(serviceUrl + "/jobs/overId/progress").reply(200, { "jobProgress": { "percentage": 100, "state": "over", "step": "Final_Step" } });
            const res = contextCaptureService.getJobProgress("overId");
            await sleep(500);
            if (axiosMock.history.get.length === 0)
                return (0, chai_1.expect)(axiosMock.history.get.length).equal(1, "Mock adapter has not been called as expected.");
            return (0, chai_1.expect)(res).to.eventually.deep.equal({ state: reality_capture_common_1.JobState.OVER, progress: 100, step: "Final_Step" });
        });
    });
    describe("Get job properties", () => {
        it("Get job properties", async function () {
            axiosMock.onGet(serviceUrl + "/jobs/ccJob").reply(200, {
                "job": {
                    "id": "cc3d35cc-416a-4262-9714-b359da70b419",
                    "name": "Reality Modeling unit test job",
                    "type": "Full",
                    "state": "unsubmitted",
                    "createdDateTime": "2023-04-05T14:29:55Z",
                    "lastModifiedDateTime": "2023-04-05T14:29:55Z",
                    "iTwinId": "c3739cf2-9da3-487b-b03d-f58c8eb97e5b",
                    "location": "East US",
                    "email": "example@bentley.com",
                    "workspaceId": "workspaceId",
                    "costEstimationParameters": {
                        "gigaPixels": 2.1,
                        "megaPoints": 1.5,
                        "meshQuality": "Extra"
                    },
                    "executionInformation": {
                        "submittedDateTime": "2023-03-30T15:14:57Z",
                        "startedDateTime": "2023-03-30T15:22:11Z",
                        "endedDateTime": "2023-03-30T15:39:47Z",
                        "estimatedUnits": 2,
                        "warnings": [{
                                "code": "400",
                                "title": "Warning",
                                "message": "This is an warning",
                                "params": ["param1", "param2"]
                            }],
                        "errors": [{
                                "code": "400",
                                "title": "Error",
                                "message": "This is an error",
                                "params": ["param1", "param2"]
                            }]
                    },
                    "inputs": [{ "id": "imagesId" }, { "id": "ccOrientationsId" }],
                    "jobSettings": {
                        "quality": "Extra",
                        "outputs": [{
                                "format": "OPC",
                                "id": "opcId"
                            },
                            {
                                "format": "CCOrientations",
                                "id": "orientationsId"
                            }
                        ],
                        "processingEngines": 5,
                        "cacheSettings": {
                            "createCache": true,
                            "useCache": "799b11bd-71cf-481a-b284-bf48f672cd9a"
                        }
                    }
                }
            });
            const properties = contextCaptureService.getJobProperties("ccJob");
            await sleep(500);
            if (axiosMock.history.get.length === 0)
                return (0, chai_1.expect)(axiosMock.history.get.length).equal(1, "Mock adapter has not been called as expected.");
            return Promise.all([
                (0, chai_1.expect)(properties).to.eventually.have.property("name", "Reality Modeling unit test job"),
                (0, chai_1.expect)(properties).to.eventually.have.property("type", Utils_1.CCJobType.FULL),
                (0, chai_1.expect)(properties).to.eventually.have.property("iTwinId", "c3739cf2-9da3-487b-b03d-f58c8eb97e5b"),
                (0, chai_1.expect)(properties).to.eventually.have.property("id", "cc3d35cc-416a-4262-9714-b359da70b419"),
                (0, chai_1.expect)(properties).to.eventually.have.property("email", "example@bentley.com"),
                (0, chai_1.expect)(properties).to.eventually.have.property("state", reality_capture_common_1.JobState.UNSUBMITTED),
                (0, chai_1.expect)(properties).to.eventually.have.deep.property("dates", {
                    createdDateTime: "2023-04-05T14:29:55Z",
                    submissionDateTime: "2023-03-30T15:14:57Z",
                    startedDateTime: "2023-03-30T15:22:11Z",
                    endedDateTime: "2023-03-30T15:39:47Z"
                }),
                (0, chai_1.expect)(properties).to.eventually.have.property("executionCost", 2),
                (0, chai_1.expect)(properties).to.eventually.have.property("settings").that.has.property("meshQuality").to.deep.equal("Extra"),
                (0, chai_1.expect)(properties).to.eventually.have.property("settings").that.has.property("engines").to.deep.equal(5),
                (0, chai_1.expect)(properties).to.eventually.have.property("settings").that.has.property("cacheSettings").that.has.property("createCache").to.deep.equal(true),
                (0, chai_1.expect)(properties).to.eventually.have.property("settings").that.has.property("cacheSettings").that.has.property("useCache").to.deep.equal("799b11bd-71cf-481a-b284-bf48f672cd9a"),
                (0, chai_1.expect)(properties).to.eventually.have.property("settings").that.has.property("outputs").that.has.property("orientations").to.deep.equal("orientationsId"),
                (0, chai_1.expect)(properties).to.eventually.have.property("settings").that.has.property("outputs").that.has.property("opc").to.deep.equal("opcId"),
                (0, chai_1.expect)(properties).to.eventually.have.deep.property("costEstimationParameters", {
                    gigaPixels: 2.1,
                    megaPoints: 1.5,
                    meshQuality: "Extra",
                }),
            ]);
        });
    });
    describe("Get estimated cost", () => {
        it("Get estimated cost", async function () {
            const body = {
                gigaPixels: 2,
                megaPoints: 150,
                meshQuality: Utils_1.CCJobQuality.EXTRA,
            };
            axiosMock.onPatch(serviceUrl + "/jobs/validId", {
                costEstimationParameters: {
                    gigaPixels: 2,
                    megaPoints: 150,
                    meshQuality: "Extra",
                }
            }).reply(200, {
                "estimatedCost": 2.1
            });
            return (0, chai_1.expect)(contextCaptureService.getJobEstimatedCost("validId", body)).to.eventually.equal(2.1);
        });
    });
});
//# sourceMappingURL=ContextCaptureService.test.js.map