"use strict";
/*---------------------------------------------------------------------------------------------
* Copyright (c) Bentley Systems, Incorporated. All rights reserved.
* See LICENSE.md in the project root for license terms and full copyright notice.
*--------------------------------------------------------------------------------------------*/
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.sleep = void 0;
const chai_1 = __importStar(require("chai"));
const chai_as_promised_1 = __importDefault(require("chai-as-promised"));
chai_1.default.use(chai_as_promised_1.default);
const dotenv = __importStar(require("dotenv"));
const path_1 = __importDefault(require("path"));
const reality_data_client_1 = require("@itwin/reality-data-client");
const ContextCaptureService_1 = require("../ContextCaptureService");
const service_authorization_1 = require("@itwin/service-authorization");
const reality_capture_common_1 = require("@itwin/reality-capture-common");
const Utils_1 = require("../Utils");
const reality_data_transfer_1 = require("@itwin/reality-data-transfer");
async function sleep(ms) { return new Promise(resolve => setTimeout(resolve, ms)); }
exports.sleep = sleep;
describe("Reality Modeling integration tests", () => {
    let contextCaptureService;
    let realityDataTransfer;
    let iTwinId = "";
    let workspaceId = "";
    let imagesId = "";
    let ccOrientationsId = "";
    let references;
    let rdaClient;
    let jobId = "";
    let threeMXId = "";
    before(async function () {
        this.timeout(20000);
        dotenv.config({ path: path_1.default.resolve(__dirname, "../../../../../../.env") });
        iTwinId = process.env.IMJS_INTEGRATION_TESTS_PROJECT_ID ?? "";
        const clientId = process.env.IMJS_INTEGRATION_TESTS_CLIENT_ID ?? "";
        const secret = process.env.IMJS_INTEGRATION_TESTS_SECRET ?? "";
        const authorizationClient = new service_authorization_1.ServiceAuthorizationClient({
            clientId: clientId,
            clientSecret: secret,
            scope: Array.from(reality_data_transfer_1.RealityDataTransferNode.getScopes()).join(" ") + " " + Array.from(ContextCaptureService_1.ContextCaptureService.getScopes()).join(" "),
            authority: "https://ims.bentley.com",
        });
        contextCaptureService = new ContextCaptureService_1.ContextCaptureService(authorizationClient.getAccessToken.bind(authorizationClient));
        realityDataTransfer = new reality_data_transfer_1.RealityDataTransferNode(authorizationClient.getAccessToken.bind(authorizationClient));
        references = new reality_data_transfer_1.ReferenceTableNode();
        const realityDataClientOptions = {
            baseUrl: "https://api.bentley.com/reality-management",
            authorizationClient: authorizationClient,
        };
        rdaClient = new reality_data_client_1.RealityDataAccessClient(realityDataClientOptions);
    });
    // Create and get workspace
    it("Create workspace", async function () {
        this.timeout(10000);
        workspaceId = await contextCaptureService.createWorkspace("SDK integration tests reality modeling workspace", iTwinId);
        (0, chai_1.expect)(workspaceId).is.not.undefined;
        (0, chai_1.expect)(workspaceId).to.have.length(36);
    });
    it("Get workspace", async function () {
        this.timeout(10000);
        const workspace = await contextCaptureService.getWorkspace(workspaceId);
        (0, chai_1.expect)(workspace.id).to.deep.equal(workspaceId);
        (0, chai_1.expect)(workspace.name).to.deep.equal("SDK integration tests reality modeling workspace");
        (0, chai_1.expect)(workspace.iTwinId).to.deep.equal(iTwinId);
        (0, chai_1.expect)(workspace.contextCaptureVersion).to.deep.equal("2023.0");
    });
    // Create and upload inputs
    it("Upload images", async function () {
        this.timeout(60000);
        imagesId = await realityDataTransfer.uploadRealityData(path_1.default.resolve(__dirname, "../../../../../../data/CC/Images/"), "SDK integration tests images", reality_capture_common_1.RealityDataType.CC_IMAGE_COLLECTION, iTwinId);
        (0, chai_1.expect)(imagesId).is.not.undefined;
        (0, chai_1.expect)(imagesId).to.have.length(36);
        references.addReference("0", imagesId);
    });
    it("Upload CC orientations", async function () {
        this.timeout(10000);
        ccOrientationsId = await realityDataTransfer.uploadCCOrientations(path_1.default.resolve(__dirname, "../../../../../../data/CC/Orientation"), "SDK integration tests CC orientations", iTwinId, references);
        (0, chai_1.expect)(ccOrientationsId).is.not.undefined;
        (0, chai_1.expect)(ccOrientationsId).to.have.length(36);
    });
    // Create & submit job
    it("Create reality modeling job", async function () {
        this.timeout(10000);
        const settings = new Utils_1.CCJobSettings();
        settings.inputs = [imagesId, ccOrientationsId];
        settings.outputs.threeMX = "threeMX";
        settings.meshQuality = Utils_1.CCJobQuality.MEDIUM;
        jobId = await contextCaptureService.createJob(Utils_1.CCJobType.FULL, settings, "SDK integration tests reality modeling job", workspaceId);
        (0, chai_1.expect)(jobId).is.not.undefined;
        (0, chai_1.expect)(jobId).to.have.length(36);
        await contextCaptureService.submitJob(jobId);
    });
    // Get and monitor job
    it("Get reality modeling job properties", async function () {
        const jobProperties = await contextCaptureService.getJobProperties(jobId);
        (0, chai_1.expect)(jobProperties.name).to.deep.equal("SDK integration tests reality modeling job");
        (0, chai_1.expect)(jobProperties.type).to.deep.equal(Utils_1.CCJobType.FULL);
        (0, chai_1.expect)(jobProperties.iTwinId).to.deep.equal(iTwinId);
        (0, chai_1.expect)(jobProperties.settings.inputs).to.have.length(2);
        (0, chai_1.expect)(jobProperties.settings.inputs[0]).to.deep.equal(imagesId);
        (0, chai_1.expect)(jobProperties.settings.inputs[1]).to.deep.equal(ccOrientationsId);
        threeMXId = jobProperties.settings.outputs.threeMX;
        (0, chai_1.expect)(threeMXId).to.have.length(36);
        (0, chai_1.expect)(jobProperties.settings.meshQuality).to.deep.equal(Utils_1.CCJobQuality.MEDIUM);
        (0, chai_1.expect)(jobProperties.workspaceId).to.deep.equal(workspaceId);
        (0, chai_1.expect)(jobProperties.id).to.deep.equal(jobId);
        (0, chai_1.expect)(jobProperties.state).to.deep.equal(reality_capture_common_1.JobState.ACTIVE);
    });
    it("Get reality modeling job progress", async function () {
        this.timeout(10000);
        const jobProgress = await contextCaptureService.getJobProgress(jobId);
        await contextCaptureService.cancelJob(jobId);
        (0, chai_1.expect)(jobProgress.progress).to.equal(0);
        (0, chai_1.expect)(jobProgress.state).to.deep.equal(reality_capture_common_1.JobState.ACTIVE);
        (0, chai_1.expect)(jobProgress.step).to.deep.equal("PrepareStep");
    });
    // Delete inputs
    it("Delete images", async function () {
        this.timeout(10000);
        await rdaClient.deleteRealityData("", imagesId);
        try {
            await rdaClient.getRealityData("", iTwinId, imagesId);
        }
        catch (error) {
            (0, chai_1.expect)(error.message).to.include("Requested reality data is not available");
        }
    });
    it("Delete cc orientations", async function () {
        this.timeout(10000);
        await rdaClient.deleteRealityData("", ccOrientationsId);
        try {
            await rdaClient.getRealityData("", iTwinId, ccOrientationsId);
        }
        catch (error) {
            (0, chai_1.expect)(error.message).to.include("Requested reality data is not available");
        }
    });
    it("Delete workspace", async function () {
        this.timeout(10000);
        await contextCaptureService.deleteWorkspace(workspaceId);
        try {
            await contextCaptureService.getWorkspace(workspaceId);
        }
        catch (error) {
            (0, chai_1.expect)(error.message).to.include("Requested workspace is not available");
        }
    });
});
//# sourceMappingURL=ContextCapture.test.js.map